@@ -20,8 +20,7 @@ from gnomad.utils.annotations import bi_allelic_expr
 from gnomad.utils.filtering import filter_to_autosomes
 from gnomad.utils.sparse_mt import filter_ref_blocks
 
-from joint_calling import utils
-
+from joint_calling import utils, resources
 
 logger = logging.getLogger(__file__)
 logging.basicConfig(format='%(levelname)s (%(name)s %(lineno)s): %(message)s')
@@ -64,7 +63,7 @@ def compute_hail_sample_qc(
     mt = filter_ref_blocks(mt)
 
     # Remove centromeres and telomeres incase they were included and any reference blocks
-    tel_cent_ht = hl.read_table(utils.TEL_AND_CENT_HT)
+    tel_cent_ht = hl.read_table(resources.TEL_AND_CENT_HT)
     mt = mt.filter_rows(hl.is_missing(tel_cent_ht[mt.locus]))
 
     sample_qc_ht = compute_stratified_sample_qc(
@@ -92,7 +91,7 @@ def snps_not_in_gnomad(
     tmp_bucket: str,
     out_ht_path: Optional[str] = None,
     overwrite: bool = False,
-    gnomad_path: str = utils.GNOMAD_HT,
+    gnomad_path: str = resources.GNOMAD_HT,
 ) -> hl.Table:
     """
     Count the number of variants per sample that do not occur in gnomAD
@@ -159,7 +158,7 @@ def infer_sex(
 
     ht = annotate_sex(
         mt,
-        excluded_intervals=hl.read_table(utils.TEL_AND_CENT_HT),
+        excluded_intervals=hl.read_table(resources.TEL_AND_CENT_HT),
         included_intervals=target_regions,
         gt_expr='LGT',
     )
